package util

import (
	"bytes"
	"fmt"
	"git.168cad.top/zhengqiuyun/rym-util/exception"
	"github.com/gin-gonic/gin"
	"io"
	"net/http"
	"strconv"
	"strings"
)

func ParamInt64(c *gin.Context, key string) int64 {
	return int64(ParamInt(c, key))
}

func ParamInt32(c *gin.Context, key string) int32 {
	return int32(ParamInt(c, key))
}

func ParamInt16(c *gin.Context, key string) int16 {
	return int16(ParamInt(c, key))
}

func ParamInt8(c *gin.Context, key string) int8 {
	return int8(ParamInt(c, key))
}

func ParamUint64(c *gin.Context, key string) uint64 {
	return uint64(ParamInt(c, key))
}

func ParamUint32(c *gin.Context, key string) uint32 {
	return uint32(ParamInt(c, key))
}

func ParamUint16(c *gin.Context, key string) uint16 {
	return uint16(ParamInt(c, key))
}

func ParamUint8(c *gin.Context, key string) uint8 {
	return uint8(ParamInt(c, key))
}

func ParamInt(c *gin.Context, key string) int {
	v := Param(c, key)
	i, err := strconv.Atoi(v)
	if err != nil {
		exception.ThrowsErrS("PARAMS_ERR", "请传入正确的数字")
	}
	return i
}

func Param(c *gin.Context, key string) string {
	v, ok := c.GetQuery(key)
	if !ok || v == "" {
		exception.ThrowsErrS("PARAMS_ERR", fmt.Sprintf("%s不能为空", key))
	}
	return v
}

const (
	ApplicationJSON = "application/json"
	XmlForm         = "application/x-www-form-urlencoded;charset=utf-8"
)

func Get(url string, client http.Client) ([]byte, error) {
	rep, err := client.Get(url)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()
	data, err := io.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}

func PostFormStr(url string, params string, header map[string]string, client http.Client) ([]byte, error) {
	p := StrToUrlValue(params)
	requestStr := p.Encode()
	buf := strings.NewReader(requestStr)
	request, err := http.NewRequest(http.MethodPost, url, buf)
	if err != nil {
		return nil, err
	}
	request.Header.Add("Content-Type", XmlForm)
	if header != nil {
		for k, v := range header {
			request.Header.Add(k, v)
		}
	}

	response, err := client.Do(request)
	if err != nil {
		return nil, err
	}
	defer response.Body.Close()
	data, err := io.ReadAll(response.Body)
	if err != nil {
		return nil, err
	}

	return data, err
}

func PostJSONStr(url string, params string, header map[string]string, client http.Client) ([]byte, error) {
	request, err := http.NewRequest(http.MethodPost, url, bytes.NewBufferString(params))
	if err != nil {
		return nil, err
	}
	request.Header.Add("Content-Type", ApplicationJSON)
	if header != nil {
		for k, v := range header {
			request.Header.Add(k, v)
		}
	}

	response, err := client.Do(request)
	if err != nil {
		return nil, err
	}
	defer response.Body.Close()
	data, err := io.ReadAll(response.Body)
	if err != nil {
		return nil, err
	}

	return data, err
}
